# OmniDoc

Convert between many document formats!

Create easy sphinx based websites using any format like word/markdown/rst

Gitter: https://gitter.im/omnidoc/community


# How to test

```
pip install pytest
pytest
```